@@ -1,11 +1,11 @@
-# $Id: ReadWrite.pm,v 1.71 2005/03/22 08:04:09 rcaputo Exp $
+# $Id: ReadWrite.pm,v 1.72 2005/08/19 16:12:46 rcaputo Exp $
 
 package POE::Wheel::ReadWrite;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.71 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my@r=(q$Revision: 1.72 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 use Carp qw( croak carp );
 use POE qw(Wheel Driver::SysRW Filter::Line);
@@ -385,7 +385,15 @@ sub DESTROY {
 
   # Turn off the select.  This is a problem if a wheel is being
   # swapped, since it will turn off selects for the other wheel.
-  $poe_kernel->select($self->[HANDLE_INPUT]);
+  if ($self->[HANDLE_INPUT]) {
+    $poe_kernel->select($self->[HANDLE_INPUT]);
+    $self->[HANDLE_INPUT] = undef;
+  }
+
+  if ($self->[HANDLE_OUTPUT]) {
+    $poe_kernel->select($self->[HANDLE_OUTPUT]);
+    $self->[HANDLE_OUTPUT] = undef;
+  }
 
   if ($self->[STATE_READ]) {
     $poe_kernel->state($self->[STATE_READ]);
